@@ -271,6 +271,10 @@ qpwgraph_form::qpwgraph_form (
 		SIGNAL(toggled(bool)),
 		SLOT(patchbayExclusive(bool)));
 
+	QObject::connect(m_ui.patchbayAutoPinAction,
+		SIGNAL(toggled(bool)),
+		SLOT(patchbayAutoPin(bool)));
+
 	QObject::connect(m_ui.patchbayEditAction,
 		SIGNAL(toggled(bool)),
 		SLOT(patchbayEdit(bool)));
@@ -281,10 +285,6 @@ qpwgraph_form::qpwgraph_form (
 		SIGNAL(triggered(bool)),
 		SLOT(patchbayUnpin()));
 
-	QObject::connect(m_ui.patchbayScanAction,
-		SIGNAL(triggered(bool)),
-		SLOT(patchbayScan()));
-
 	QObject::connect(m_ui.graphQuitAction,
 		SIGNAL(triggered(bool)),
 		SLOT(closeQuit()));
@@ -650,11 +650,9 @@ void qpwgraph_form::patchbayUnpin (void)
 }
 
 
-void qpwgraph_form::patchbayScan (void)
+void qpwgraph_form::patchbayAutoPin ( bool on )
 {
-	qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
-	if (patchbay)
-		patchbay->scan();
+	m_ui.graphCanvas->setPatchbayAutoPin(on);
 
 	stabilize();
 }
@@ -1028,8 +1026,10 @@ void qpwgraph_form::refresh (void)
 #endif
 
 	if (nchanged > 0) {
-		patchbayScan();
-	//	stabilize();
+		qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
+		if (patchbay)
+			patchbay->scan();
+		stabilize();
 	}
 
 	QTimer::singleShot(300, this, SLOT(refresh()));
@@ -1055,7 +1055,6 @@ void qpwgraph_form::stabilize (void)
 	setWindowTitle(title);
 
 	m_ui.patchbayExclusiveAction->setEnabled(is_activated);
-	m_ui.patchbayScanAction->setEnabled(is_activated);
 	m_ui.patchbaySaveAction->setEnabled(is_dirty);
 
 	m_ui.patchbayPinAction->setEnabled(canvas->canPatchbayPin());
@@ -1455,10 +1454,13 @@ void qpwgraph_form::restoreState (void)
 	if (patchbay) {
 		const bool is_activated = m_config->isPatchbayActivated();
 		const bool is_exclusive = m_config->isPatchbayExclusive();
+		const bool is_autopin = m_config->isPatchbayAutoPin();
 		m_ui.patchbayActivatedAction->setChecked(is_activated);
 		m_ui.patchbayExclusiveAction->setChecked(is_exclusive);
+		m_ui.patchbayAutoPinAction->setChecked(is_autopin);
 		patchbay->setActivated(is_activated);
 		patchbay->setExclusive(is_exclusive);
+		m_ui.graphCanvas->setPatchbayAutoPin(is_autopin);
 	}
 
 	m_ui.viewMenubarAction->setChecked(m_config->isMenubar());
@@ -1536,6 +1538,7 @@ void qpwgraph_form::saveState (void)
 	m_config->setPatchbayToolbar(m_ui.patchbayToolbar->isVisible());
 	m_config->setMenubar(m_ui.MenuBar->isVisible());
 
+	m_config->setPatchbayAutoPin(m_ui.patchbayAutoPinAction->isChecked());
 	m_config->setPatchbayExclusive(m_ui.patchbayExclusiveAction->isChecked());
 	m_config->setPatchbayActivated(m_ui.patchbayActivatedAction->isChecked());
 	m_config->setPatchbayPath(m_patchbay_path);
